@@ -5,10 +5,15 @@ exams2moodle <- function(file, n = 1L, nsamp = NULL, dir = ".",
   resolution = 100, width = 4, height = 4, encoding = "", 
   iname = TRUE, stitle = NULL, testid = FALSE, zip = FALSE,
   num = NULL, mchoice = NULL, schoice = mchoice, string = NULL, cloze = NULL,
-  points = NULL, rule = NULL, pluginfile = TRUE, ...)
+  points = NULL, rule = NULL, pluginfile = TRUE,
+  converter = NULL, ...)
 {
+  ## default converter is "ttm" if all exercises are Rnw, otherwise "pandoc"
+  if(is.null(converter)) {
+    converter <- if(any(tolower(tools::file_ext(unlist(file))) == "rmd")) "pandoc" else "ttm"
+  }
   ## set up .html transformer
-  htmltransform <- make_exercise_transform_html(..., base64 = !pluginfile)
+  htmltransform <- make_exercise_transform_html(converter = converter, ..., base64 = !pluginfile)
 
   ## generate the exam
   if(encoding == "") encoding <- "UTF-8"
@@ -205,7 +210,7 @@ exams2moodle <- function(file, n = 1L, nsamp = NULL, dir = ".",
 make_question_moodle <-
 make_question_moodle23 <- function(name = NULL, solution = TRUE, shuffle = FALSE, penalty = 0,
   answernumbering = "abc", usecase = FALSE, cloze_mchoice_display = "MULTICHOICE",
-  truefalse = c("True", "False"), enumerate = TRUE,
+  truefalse = c("True", "False"), enumerate = TRUE, abstention = NULL,
   eval = list(partial = TRUE, negative = FALSE, rule = "false2"))
 {
   function(x) {
@@ -231,6 +236,11 @@ make_question_moodle23 <- function(name = NULL, solution = TRUE, shuffle = FALSE
     ## question name
     if(is.null(name)) name <- x$metainfo$name
 
+    ## extra abstention option
+    if(is.null(abstention)) abstention <- x$metainfo$abstention
+    if(is.null(abstention) || identical(abstention, FALSE)) abstention <- ""
+    if(isTRUE(abstention)) abstention <- "Abstention"
+
     ## start the question xml
     xml <- c(
       paste('\n<question type="', type, '">', sep = ''),
@@ -296,6 +306,17 @@ make_question_moodle23 <- function(name = NULL, solution = TRUE, shuffle = FALSE
           '</answer>'
         )
       }
+
+      ## add abstention option (if any)
+      if(abstention != "") {
+        xml <- c(xml,
+          '<answer fraction="0" format="html">',
+          '<text><![CDATA[<p>',
+          abstention,
+          '</p>]]></text>',
+          '</answer>'
+        )
+      }
     }
 
     ## numeric question processing
